@@ -101,7 +101,8 @@ public:
 /**
  * Scope lock.
  */
-class epicsShareClass ScopedLock : private epics::pvData::NoDefaultMethods {
+class epicsShareClass ScopedLock {
+    EPICS_NOT_COPYABLE(ScopedLock)
 public:
 
     explicit ScopedLock(Lockable::shared_pointer const & li)
@@ -179,7 +180,7 @@ private:
 /**
  * Base interface for all channel requests (aka. Operations).
  */
-class epicsShareClass ChannelRequest : public virtual Destroyable, public Lockable, private epics::pvData::NoDefaultMethods {
+class epicsShareClass ChannelRequest : public virtual Destroyable, public Lockable {
 public:
     POINTER_DEFINITIONS(ChannelRequest);
 
@@ -211,8 +212,7 @@ public:
     virtual void lastRequest() = 0;
 
 private:
-    ChannelRequest(const ChannelRequest&);
-    ChannelRequest& operator=(const ChannelRequest&);
+    EPICS_NOT_COPYABLE(ChannelRequest)
 };
 
 /**
@@ -376,11 +376,13 @@ public:
 /**
  *
  */
-class epicsShareClass ChannelFind : public Destroyable, private epics::pvData::NoDefaultMethods {
+class epicsShareClass ChannelFind : public Destroyable {
+    EPICS_NOT_COPYABLE(ChannelFind)
 public:
     POINTER_DEFINITIONS(ChannelFind);
     typedef ChannelFindRequester requester_type;
 
+    ChannelFind() {}
     virtual ~ChannelFind() {}
 
     virtual std::tr1::shared_ptr<ChannelProvider> getChannelProvider() = 0;
@@ -391,6 +393,8 @@ public:
     static ChannelFind::shared_pointer buildDummy(const std::tr1::shared_ptr<ChannelProvider>& provider);
 };
 
+struct PeerInfo; // see pv/security.h
+
 /**
  *
  */
@@ -408,6 +412,30 @@ public:
         const epics::pvData::Status& status,
         ChannelFind::shared_pointer const & channelFind,
         bool wasFound) = 0;
+
+    /**
+     * @brief Return information on requesting peer if applicable.
+     *
+     * A server-type ChannelProvider will use this method to discover if a remote client
+     * has provided credentials which may be used in access control decisions.
+     *
+     * The returned PeerInfo is only required to have valid values for: peer, transport, and transportVersion.
+     * PeerInfo::authority may be empty if authentication has not yet occured (UDP search).
+     *
+     * Default implementation returns NULL.
+     *
+     * isConnected()==true and getPeerInfo()==NULL when the ChannelProvider does not provide
+     * information about the peer.  This should be treated as an unauthenticated, anonymous,
+     * peer.
+     *
+     * The returned instance must not change, and a different instance should be returned
+     * if/when peer information changes (eg. after reconnect).
+     *
+     * May return !NULL when !isConnected().  getPeerInfo() must be called _before_
+     * testing isConnected() in situations where connection state is being polled.
+     */
+    virtual std::tr1::shared_ptr<const PeerInfo> getPeerInfo()
+    { return std::tr1::shared_ptr<const PeerInfo>(); }
 };
 
 /**
@@ -817,7 +845,6 @@ public:
 
 };
 
-
 class ChannelRequester;
 
 /**
@@ -833,8 +860,9 @@ class ChannelRequester;
  */
 class epicsShareClass Channel :
     public Requester,
-    public Destroyable,
-    private epics::pvData::NoDefaultMethods {
+    public Destroyable
+{
+    EPICS_NOT_COPYABLE(Channel)
 public:
     POINTER_DEFINITIONS(Channel);
     typedef ChannelRequester requester_type;
@@ -1130,6 +1158,26 @@ public:
      * @param connectionState The new connection state.
      */
     virtual void channelStateChange(Channel::shared_pointer const & channel, Channel::ConnectionState connectionState) = 0;
+
+    /**
+     * @brief Return information on connected peer if applicable.
+     *
+     * A server-type ChannelProvider will use this method to discover if a remote client
+     * has provided credentials which may be used in access control decisions.
+     *
+     * Default implementation returns NULL.
+     *
+     * isConnected()==true and getPeerInfo()==NULL when the ChannelProvider does not provide
+     * information about the peer.  This should be treated as an unauthenticated, anonymous,
+     * peer.
+     *
+     * The returned instance must not change, and a different instance should be returned
+     * if/when peer information changes (eg. after reconnect).
+     *
+     * May return !NULL when !isConnected().  getPeerInfo() must be called _before_
+     * testing isConnected() in situations where connection state is being polled.
+     */
+    virtual std::tr1::shared_ptr<const PeerInfo> getPeerInfo();
 };
 
 //! Used when ChannelProvider::createChannel() is passed a NULL ChannelRequester
@@ -1154,10 +1202,9 @@ enum FlushStrategy {
  *
  * Uniquely configurable (via ChannelProviderFactory::newInstance(Configuration*)
  */
-class epicsShareClass ChannelProvider : public Destroyable, private epics::pvData::NoDefaultMethods
+class epicsShareClass ChannelProvider : public Destroyable
 {
-    ChannelProvider(const ChannelProvider&);
-    ChannelProvider& operator=(const ChannelProvider&);
+    EPICS_NOT_COPYABLE(ChannelProvider)
 public:
     POINTER_DEFINITIONS(ChannelProvider);
 
@@ -1246,10 +1293,12 @@ public:
 /**
  * <code>ChanneProvider</code> factory interface.
  */
-class epicsShareClass ChannelProviderFactory : private epics::pvData::NoDefaultMethods {
+class epicsShareClass ChannelProviderFactory {
+    EPICS_NOT_COPYABLE(ChannelProviderFactory)
 public:
     POINTER_DEFINITIONS(ChannelProviderFactory);
 
+    ChannelProviderFactory() {}
     virtual ~ChannelProviderFactory() {}
 
     /**
